import { CSSProperties, FC, ReactNode } from 'react';
import { FcrBasicConfirmDialog } from './basic-confirm-dialog';
import { FcrClassDialog } from './class-dialog';
import { FcrConfirmDialog } from './confirm-dialog';
import './index.css';
export interface BaseDialogProps {
    /**
     * 对话框是否显示
     */
    /** @en
     * Whether the dialog is visible or not.
     */
    visible?: boolean;
    /**
     * 对话框关闭的回调，点击关闭按钮或蒙层时触发
     */
    /** @en
     * Specify a function that will be called when a user clicks mask, close button on top right or Cancel button
     */
    onClose?: () => void;
    /**
     * 是否可以点击蒙层关闭
     */
    /** @en
     * Whether to close the modal dialog when the mask (area outside the modal) is clicked
     */
    maskClosable?: boolean;
    /**
     * 对话框宽度
     */
    /** @en
     * Width of the dialog
     */
    width?: number;
    /**
     * 对话框类名
     */
    /** @en
     * classname of the dialog
     */
    classNames?: string;
    /**
     * 是否显示对话框关闭按钮
     */
    /** @en
     * Whether a close (x) button is visible on top right of the dialog or not
     */
    closable?: boolean;
    /**
     * 自定义对话框关闭按钮
     */
    /** @en
     * Custom close icon
     */
    closeIcon?: ReactNode;
    afterClose?: () => void;
    mask?: boolean;
    bodyStyle?: CSSProperties;
    style?: CSSProperties;
    wrapClassName?: string;
    getContainer?: false | string | HTMLElement | (() => HTMLElement) | undefined;
    center?: boolean;
    destroyOnClose?: boolean;
    maskStyle?: CSSProperties;
    wrapStyle?: CSSProperties;
    zIndex?: number;
    forceRender?: boolean;
}
declare const BaseDialog: FC<React.PropsWithChildren<BaseDialogProps>>;
export { FcrConfirmDialog, FcrClassDialog, BaseDialog, FcrBasicConfirmDialog };
export { FcrDialogApi } from './confirm';
