import React, { CSSProperties, FC } from 'react';
import { FcrIconProps } from '../icon';
import './index.css';
export type InputProps = {
    /**
     * 输入框的提示符
     */
    /** @en
     * Placeholder of the input box
     */
    placeholder?: string;
    /**
     * 输入框中的值
     */
    /** @en
     * Value of the input box
     */
    value?: string;
    /**
     * 输入框的标签，一般展示在输入框的头部，提示用户需要输入的内容
     */
    /** @en
     * The label of the input box, usually displayed at the head of the input box, prompting the user to enter the content
     */
    label?: string;
    /**
     * 输入框是否禁用
     */
    /** @en
     * Whether the input box is disabled
     */
    disabled?: boolean;
    /**
     * 输入框前置图标，仅在 variant = rounded 时生效
     */
    /** @en
     * Input box front icon, takes effect only if variant = rounded
     */
    iconPrefix?: FcrIconProps;
    /**
     * 输入框的尺寸：
     * medium - 中等(default)
     * large - 大
     */
    /** @en
     * Size of the input box:
     * medium
     * large
     */
    size?: 'large' | 'medium' | 'small' | 'mini';
    /**
     * 值变更事件
     * @param value 变更值
     */
    /** @en
     * Change event of the input's value
     * @param value changed value
     */
    onChange?: (value: string) => void;
    onBlur?: () => void;
    onKeyDown?: (event: React.KeyboardEvent) => void;
    onKeyUp?: (event: React.KeyboardEvent) => void;
    allowClear?: boolean;
    autoFocus?: boolean;
    style?: CSSProperties;
    shape?: 'circle' | 'rounded';
    maxLength?: number;
    showCount?: boolean;
};
export declare const FcrInput: FC<InputProps>;
