import { FC } from 'react';
import './index.css';
export interface OptionsItem {
    text: string;
    value: string;
    render?: (option: OptionsItem) => JSX.Element;
    valueRender?: (option: OptionsItem) => JSX.Element;
    disabled?: boolean;
}
export type SelectStyleType = 'white';
export type SelectProps = {
    /**
     * 下拉框选中的值
     */
    /** @en
     * The select selected value
     */
    value?: string;
    /**
     * 下拉框的提示符
     */
    /** @en
     * Placeholder of the select
     */
    placeholder?: string;
    /**
     * 下拉框选项
     */
    /** @en
     * The select options
     */
    options?: OptionsItem[];
    /**
     * 输入框的尺寸：
     * small - 小
     * medium - 中等(default)
     * large - 大
     */
    /** @en
     * Size of the select:
     * small
     * medium
     * large
     */
    size?: 'large' | 'medium' | 'small';
    /**
     * 下拉框样式类型，可选值为 'white'
     */
    /** @en
     * Set the style type of select, can be set to 'white'.
     */
    styleType?: SelectStyleType;
    /**
     * 值变更事件
     * @param value 变更值
     */
    /** @en
     * Change event of the input's value
     * @param value changed value
     */
    onChange?: (value: string) => void;
    /**
     * 下拉框是否禁用
     */
    /** @en
     * Whether the select is disabled
     */
    disabled?: boolean;
    /**
     * 是否背景模糊（用于特殊场景，如视频设置中的摄像头设备选择）
     */
    /** @en
     * Is the background blurred (for special scenarios, such as selecting camera equipment in video settings)
     */
    blurred?: boolean;
    /**
     * 外部传入的类名
     */
    /** @en
     *  External class name
     */
    className?: string;
    /**
     * 配置是否可搜索
     */
    /** @en
     *  Configures whether to be searchable
     */
    showSearch?: boolean;
    /**
     * 自定义搜索过滤条件
     */
    /** @en
     *  Customize search filtering criteria
     */
    filterOption?: ({ value, option }: {
        value: string | undefined;
        option: OptionsItem;
    }) => boolean;
    /**
     * 标签
     */
    /** @en
     *  Extra tag
     */
    tag?: string;
};
export declare const FcrSelect: FC<SelectProps>;
