import React, { FC } from 'react';
import './index.css';
export type TextAreaProps = {
    /**
     * 文本框中的值
     */
    /** @en
     * Value of the textarea
     */
    value?: string;
    /**
     * 限制最大文本输入字数
     */
    /** @en
     * Limit the max character count of the textarea
     */
    maxCount?: number;
    /**
     * 文本框的提示符
     */
    /** @en
     * Placeholder of the textarea
     */
    placeholder?: string;
    /**
     * 文本框是否可以垂直方向拖拽更改尺寸
     */
    /** @en
     * Whether the textarea can be resized vertically
     */
    resizable?: boolean;
    /**
     * 文本框是否禁用
     */
    /** @en
     * Whether the textarea is disabled
     */
    disabled?: boolean;
    /**
     * 值变更事件
     * @param value 变更值
     */
    /** @en
     * Change event of the textarea's value
     * @param value changed value
     */
    onChange?: (value: string) => void;
    showCount?: boolean;
    onFocusChange?: (focus: boolean) => void;
    autoSize?: {
        minHeight?: number;
        maxHeight?: number;
    } | boolean;
    onKeyDown?: React.KeyboardEventHandler<HTMLTextAreaElement>;
};
export declare const FcrTextArea: React.ForwardRefExoticComponent<TextAreaProps & React.RefAttributes<{
    dom: HTMLTextAreaElement | null;
}>>;
type TextAreaBorderLessProps = {
    /**
     * 文本框的标签，一般展示在文本框的头部，提示用户需要输入的内容
     */
    /** @en
     * The label of the textarea, usually displayed at the head of the textarea, prompting the user to enter the content
     */
    label?: string;
    /**
     *
     */
    /** @en
     *
     */
    labelIcon?: React.ReactElement;
    /**
     * 文本框的提示符
     */
    /** @en
     * Placeholder of the textarea
     */
    placeholder?: string;
    /**
     * 值变更事件，只会在文本框失去焦点时触发
     * @param value 变更值
     */
    /** @en
     * Change event of the textarea's value, only fired when it lose focus
     * @param value changed value
     */
    onChange?: (value: string) => void;
    /**
     *
     */
    /** @en
     *
     */
    defaultValue?: string;
    maxLength?: number;
};
export declare const FcrTextAreaBorderLess: FC<TextAreaBorderLessProps>;
export {};
